@@ -49,26 +49,29 @@
 #' @inheritParams format_value
 #' @inheritParams get_data
 #'
-#' @seealso Vignettes [Formatting, printing and exporting tables](https://easystats.github.io/insight/articles/display.html)
+#' @seealso Vignettes
+#' [Formatting, printing and exporting tables](https://easystats.github.io/insight/articles/display.html)
 #' and [Formatting model parameters](https://easystats.github.io/parameters/articles/model_parameters_formatting.html).
 #'
 #' @note `options(insight_use_symbols = TRUE)` override the `use_symbols` argument
 #'   and always displays symbols, if possible.
-#' @examples
+#' @examplesIf require("rstanarm", warn.conflicts = FALSE) && require("parameters", , warn.conflicts = FALSE)
 #' format_table(head(iris), digits = 1)
 #'
-#' if (require("parameters")) {
-#'   x <- model_parameters(lm(Sepal.Length ~ Species * Sepal.Width, data = iris))
-#'   as.data.frame(format_table(x))
-#'   as.data.frame(format_table(x, p_digits = "scientific"))
-#' }
+#' m <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
+#' x <- parameters::model_parameters(m)
+#' as.data.frame(format_table(x))
+#' as.data.frame(format_table(x, p_digits = "scientific"))
+#'
 #' \donttest{
-#' if (require("rstanarm", warn.conflicts = FALSE) &&
-#'   require("parameters", , warn.conflicts = FALSE)) {
-#'   model <- stan_glm(Sepal.Length ~ Species, data = iris, refresh = 0, seed = 123)
-#'   x <- model_parameters(model, ci = c(0.69, 0.89, 0.95))
-#'   as.data.frame(format_table(x))
-#' }
+#' model <- rstanarm::stan_glm(
+#'   Sepal.Length ~ Species,
+#'   data = iris,
+#'   refresh = 0,
+#'   seed = 123
+#' )
+#' x <- parameters::model_parameters(model, ci = c(0.69, 0.89, 0.95))
+#' as.data.frame(format_table(x))
 #' }
 #' @return A data frame. Note that `format_table()` converts all columns
 #' into character vectors!
@@ -89,10 +92,10 @@ format_table <- function(x,
                          use_symbols = getOption("insight_use_symbols", FALSE),
                          verbose = TRUE,
                          ...) {
-  # sanity check
+  # validation check
   if (is.null(x) || (is.data.frame(x) && nrow(x) == 0)) {
     if (isTRUE(verbose)) {
-      message("Can't format table, data frame is empty.")
+      format_alert("Can't format table, data frame is empty.")
     }
     return(NULL)
   }
@@ -110,29 +113,11 @@ format_table <- function(x,
 
   # Format parameters names ----
   if (pretty_names && !is.null(att$pretty_names)) {
-    # remove strings with NA names
-    att$pretty_names <- att$pretty_names[!is.na(names(att$pretty_names))]
-    if (length(att$pretty_names) != length(x$Parameter)) {
-      match_pretty_names <- match(names(att$pretty_names), x$Parameter)
-      match_pretty_names <- match_pretty_names[!is.na(match_pretty_names)]
-      if (length(match_pretty_names)) {
-        x$Parameter[match_pretty_names] <- att$pretty_names[x$Parameter[match_pretty_names]]
-      }
-    } else {
-      match_pretty_names <- att$pretty_names[x$Parameter]
-      if (!anyNA(match_pretty_names)) {
-        x$Parameter <- att$pretty_names[x$Parameter]
-      } else {
-        match_pretty_names <- match(names(att$pretty_names), x$Parameter)
-        match_pretty_names <- match_pretty_names[!is.na(match_pretty_names)]
-        if (length(match_pretty_names)) {
-          x$Parameter[match_pretty_names] <- att$pretty_names[x$Parameter[match_pretty_names]]
-        }
-      }
-    }
+    shared <- intersect(x$Parameter, names(att$pretty_names))
+    index <- match(shared, x$Parameter)
+    x$Parameter[index] <- as.vector(att$pretty_names[x$Parameter[index]])
   }
 
-
   # Format specific columns ----
   if ("n_Obs" %in% names(x)) x$n_Obs <- format_value(x$n_Obs, protect_integers = TRUE)
   if ("n_Missing" %in% names(x)) x$n_Missing <- format_value(x$n_Missing, protect_integers = TRUE)
@@ -155,13 +140,16 @@ format_table <- function(x,
 
 
   # Main CI and Prediction Intervals ----
-  x <- .format_main_ci_columns(x, att, ci_digits, ci_width, ci_brackets, zap_small)
-  x <- .format_main_ci_columns(x, att, ci_digits, ci_width, ci_brackets, zap_small, ci_name = "PI")
-  x <- .format_broom_ci_columns(x, ci_digits, ci_width, ci_brackets, zap_small)
+  x <- .format_main_ci_columns(x, att, ci_digits, zap_small, ci_width, ci_brackets)
+  x <- .format_main_ci_columns(x, att, ci_digits, zap_small, ci_width, ci_brackets, ci_name = "PI")
+  x <- .format_broom_ci_columns(x, ci_digits, zap_small, ci_width, ci_brackets)
 
 
+  # Misc / Effect Sizes
+  x <- .format_effectsize_columns(x, use_symbols)
+
   # Other CIs ----
-  out <- .format_other_ci_columns(x, att, ci_digits, ci_width, ci_brackets, zap_small)
+  out <- .format_other_ci_columns(x, att, ci_digits, zap_small, ci_width, ci_brackets)
   x <- out$x
   other_ci_colname <- out$other_ci_colname
 
@@ -181,8 +169,6 @@ format_table <- function(x,
   )
 
 
-  # Misc / Effect Sizes
-  x <- .format_effectsize_columns(x, use_symbols)
 
 
   # metafor ----
@@ -246,39 +232,32 @@ format_table <- function(x,
 # Format various p-values, coming from different easystats-packages
 # like bayestestR (p_ROPE, p_MAP) or performance (p_Chi2)
 
-.format_p_values <- function(x, stars = FALSE, p_digits) {
-  # Specify stars for which column
+.format_p_values <- function(x, p_digits, stars = FALSE) {
+  # Specify stars for which column (#656)
   if (is.character(stars)) {
-    starlist <- list("p" = FALSE)
+    starlist <- list(p = FALSE)
     starlist[stars] <- TRUE
   } else {
-    starlist <- list("p" = stars)
+    starlist <- list(p = stars)
   }
 
-  if ("p" %in% names(x)) {
-    x$p <- format_p(
-      x$p,
-      stars = starlist[["p"]],
-      name = NULL,
-      missing = "",
-      digits = p_digits
-    )
-    x$p <- format(x$p, justify = "left")
-  }
-  if ("p.value" %in% names(x)) {
-    x$p.value <- format_p(
-      x$p.value,
-      stars = starlist[["p"]],
-      name = NULL,
-      missing = "",
-      digits = p_digits
-    )
-    x$p.value <- format(x$p.value, justify = "left")
+  for (pv in c("p", "p.value", "SGPV")) {
+    if (pv %in% names(x)) {
+      x[[pv]] <- format_p(
+        x[[pv]],
+        stars = starlist[["p"]],
+        name = NULL,
+        missing = "",
+        digits = p_digits
+      )
+      x[[pv]] <- format(x[[pv]], justify = "left")
+    }
   }
 
   for (stats in c(
     "p_CochransQ", "p_Omnibus", "p_Chi2", "p_Baseline", "p_RMSEA", "p_ROPE",
-    "p_MAP", "Wu_Hausman_p", "Sargan_p", "p_Omega2", "p_LR", "p_calibrated"
+    "p_MAP", "Wu_Hausman_p", "Sargan_p", "p_Omega2", "p_LR", "p_calibrated",
+    "weak_instruments_p"
   )) {
     if (stats %in% names(x)) {
       x[[stats]] <- format_p(
@@ -311,10 +290,10 @@ format_table <- function(x,
   # df for errors
   if ("df_error" %in% names(x)) {
     x$df_error <- format_value(x$df_error, protect_integers = TRUE)
-    if (!("df" %in% names(x))) {
-      names(x)[names(x) == "df_error"] <- "df"
-    } else {
+    if ("df" %in% names(x)) {
       names(x)[names(x) == "df_error"] <- "df (error)"
+    } else {
+      names(x)[names(x) == "df_error"] <- "df"
     }
   }
   # denominator and numerator df
@@ -336,6 +315,8 @@ format_table <- function(x,
 
 .format_effectsize_columns <- function(x, use_symbols) {
   names(x)[names(x) == "Cohens_d"] <- "Cohen's d"
+  names(x)[names(x) == "Cohens_d_CI_low"] <- "Cohen's d_CI_low"
+  names(x)[names(x) == "Cohens_d_CI_high"] <- "Cohen's d_CI_high"
   names(x)[names(x) == "Cohens_w"] <- "Cohen's w"
   names(x)[names(x) == "Cohens_h"] <- "Cohen's h"
   names(x)[names(x) == "Cohens_g"] <- "Cohen's g"
@@ -453,9 +434,9 @@ format_table <- function(x,
 .format_main_ci_columns <- function(x,
                                     att,
                                     ci_digits,
+                                    zap_small,
                                     ci_width = "auto",
                                     ci_brackets = TRUE,
-                                    zap_small,
                                     ci_name = "CI") {
   # Main CI
   ci_low <- names(x)[grep(paste0("^", ci_name, "_low"), names(x))]
@@ -468,14 +449,12 @@ format_table <- function(x,
   if (length(ci_low) >= 1 && length(ci_low) == length(ci_high)) {
     if (!is.null(ci_value)) {
       ci_value <- ci_value[!is.na(ci_value)]
-      if (n_unique(ci_value) > 1) {
+      if (n_unique(ci_value) > 1L) {
         ci_value <- unique(ci_value)
       } else {
         ci_value <- unique(ci_value)[1]
       }
-    } else if (!is.null(x$CI)) {
-      ci_value <- unique(x$CI[!is.na(x$CI)])[1]
-    } else {
+    } else if (is.null(x$CI)) {
       # all these edge cases... for some objects in "parameters::model_parameters()",
       # when we have multiple ci-levels, column names can be "CI_low_0.8" or
       # "CI_low_0.95" etc. - this is handled here, if we have no ci-attribute
@@ -486,12 +465,14 @@ format_table <- function(x,
       } else {
         ci_value <- NULL
       }
+    } else {
+      ci_value <- unique(x$CI[!is.na(x$CI)])[1]
     }
     x$CI <- NULL
 
     if (is.null(ci_value)) {
       ci_colname <- ci_name
-    } else if (isTRUE(tolower(ci_method) %in% "si")) {
+    } else if (isTRUE(tolower(ci_method) == "si")) {
       ci_colname <- sprintf("BF = %.5g SI", ci_value)
     } else {
       ci_colname <- sprintf("%g%% %s", ci_value * 100, ci_name)
@@ -524,18 +505,18 @@ format_table <- function(x,
 
 
 
-.format_other_ci_columns <- function(x, att, ci_digits, ci_width = "auto", ci_brackets = TRUE, zap_small) {
+.format_other_ci_columns <- function(x, att, ci_digits, zap_small, ci_width = "auto", ci_brackets = TRUE) {
   other_ci_low <- names(x)[endsWith(names(x), "_CI_low")]
   other_ci_high <- names(x)[endsWith(names(x), "_CI_high")]
   if (length(other_ci_low) >= 1 && length(other_ci_low) == length(other_ci_high)) {
-    other <- unlist(strsplit(other_ci_low, "_CI_low$"))
+    other <- unlist(strsplit(other_ci_low, "_CI_low$"), use.names = FALSE)
 
     # CI percentage
     if (length(other) == 1 && !is.null(att[[paste0("ci_", other)]])) {
       other_ci_colname <- sprintf("%s %g%% CI", other, unique(stats::na.omit(att[[paste0("ci_", other)]])) * 100)
     } else if (!is.null(att[["ci"]])) {
       other_ci_colname <- sprintf("%s %g%% CI", other, unique(stats::na.omit(att[["ci"]])) * 100)
-    } else if (length(other == 1) && paste0(other, "_CI") %in% colnames(x)) {
+    } else if (length(other) == 1 && paste0(other, "_CI") %in% colnames(x)) {
       other_ci_colname <- sprintf("%s %g%% CI", other, unique(stats::na.omit(x[[paste0(other, "_CI")]])) * 100)
     } else {
       other_ci_colname <- paste(other, " CI")
@@ -574,9 +555,9 @@ format_table <- function(x,
 
 .format_broom_ci_columns <- function(x,
                                      ci_digits,
+                                     zap_small,
                                      ci_width = "auto",
-                                     ci_brackets = TRUE,
-                                     zap_small) {
+                                     ci_brackets = TRUE) {
   if (!any(grepl("conf.low", names(x), fixed = TRUE))) {
     return(x)
   }
@@ -587,7 +568,7 @@ format_table <- function(x,
     {
       ci_low <- names(x)[which(names(x) == "conf.low")]
       ci_high <- names(x)[which(names(x) == "conf.high")]
-      x$conf.int <- format_ci(
+      x$conf.low <- format_ci(
         x[[ci_low]],
         x[[ci_high]],
         ci = NULL,
@@ -596,7 +577,7 @@ format_table <- function(x,
         brackets = ci_brackets,
         zap_small = zap_small
       )
-      x$conf.low <- NULL
+      names(x)[names(x) == "conf.low"] <- "conf.int"
       x$conf.high <- NULL
       x
     },
@@ -608,7 +589,7 @@ format_table <- function(x,
 
 
 
-.format_rope_columns <- function(x, ci_width = "auto", ci_brackets = TRUE, zap_small) {
+.format_rope_columns <- function(x, zap_small, ci_width = "auto", ci_brackets = TRUE) {
   if (all(c("ROPE_low", "ROPE_high") %in% names(x))) {
     x$ROPE_low <- format_ci(
       x$ROPE_low,
@@ -628,7 +609,7 @@ format_table <- function(x,
 
 
 .format_std_columns <- function(x, other_ci_colname, digits, zap_small) {
-  std_cols <- names(x)[grepl("Std_", names(x))]
+  std_cols <- names(x)[grepl("Std_", names(x), fixed = TRUE)]
   if (length(std_cols) == 0) {
     return(x)
   }
@@ -658,25 +639,28 @@ format_table <- function(x,
 
 
 .format_bayes_columns <- function(x,
+                                  zap_small,
                                   stars = FALSE,
                                   rope_digits = 2,
-                                  zap_small,
                                   ci_width = "auto",
                                   ci_brackets = TRUE,
                                   exact = TRUE) {
   # Specify stars for which column
   if (is.character(stars)) {
-    starlist <- list("BF" = FALSE, "pd" = FALSE)
+    starlist <- list(BF = FALSE, pd = FALSE)
     starlist[stars] <- TRUE
   } else {
-    starlist <- list("BF" = stars, "pd" = stars)
+    starlist <- list(BF = stars, pd = stars)
   }
 
   # Indices
-  if ("BF" %in% names(x)) x$BF <- format_bf(x$BF, name = NULL, stars = starlist[["BF"]], exact = exact)
+  if ("BF" %in% names(x)) {
+    x$BF <- format_bf(x$BF, name = NULL, stars = starlist[["BF"]], exact = exact)
+  }
   if ("log_BF" %in% names(x)) {
-    x$BF <- format_bf(exp(x$log_BF), name = NULL, stars = starlist[["BF"]], exact = exact)
-    x$log_BF <- NULL
+    x$log_BF <- format_bf(exp(x$log_BF), name = NULL, stars = starlist[["BF"]], exact = exact)
+    x$BF <- NULL
+    colnames(x)[colnames(x) == "log_BF"] <- "BF"
   }
   if ("pd" %in% names(x)) x$pd <- format_pd(x$pd, name = NULL, stars = starlist[["pd"]])
   if ("Rhat" %in% names(x)) x$Rhat <- format_value(x$Rhat, digits = 3)
@@ -687,17 +671,28 @@ format_table <- function(x,
     x$ROPE_Percentage <- format_rope(x$ROPE_Percentage, name = NULL, digits = rope_digits)
     names(x)[names(x) == "ROPE_Percentage"] <- "% in ROPE"
   }
-  x <- .format_rope_columns(x, ci_width, ci_brackets, zap_small)
+  x <- .format_rope_columns(
+    x,
+    zap_small = zap_small,
+    ci_width = ci_width,
+    ci_brackets = ci_brackets
+  )
 
 
   # Priors
   if ("Prior_Location" %in% names(x)) x$Prior_Location <- format_value(x$Prior_Location, protect_integers = TRUE)
   if ("Prior_Scale" %in% names(x)) x$Prior_Scale <- format_value(x$Prior_Scale, protect_integers = TRUE)
-  if ("Prior_Distribution" %in% names(x)) x$Prior_Distribution <- ifelse(is.na(x$Prior_Distribution), "", x$Prior_Distribution)
+  if ("Prior_Distribution" %in% names(x)) {
+    x$Prior_Distribution <- ifelse(
+      is.na(x$Prior_Distribution), "", x$Prior_Distribution
+    )
+  }
   if ("Prior_df" %in% names(x)) x$Prior_df <- format_value(x$Prior_df, protect_integers = TRUE)
   if (all(c("Prior_Distribution", "Prior_df") %in% names(x))) {
     missing_df <- is.na(x$Prior_df) | x$Prior_df == ""
-    x$Prior_Distribution[!missing_df] <- paste0(x$Prior_Distribution[!missing_df], " (df=", x$Prior_df[!missing_df], ")")
+    x$Prior_Distribution[!missing_df] <- paste0(
+      x$Prior_Distribution[!missing_df], " (df=", x$Prior_df[!missing_df], ")"
+    )
   }
   if (all(c("Prior_Distribution", "Prior_Location", "Prior_Scale") %in% names(x))) {
     x$Prior <- paste0(
@@ -740,6 +735,8 @@ format_table <- function(x,
   if ("Performance_Score" %in% names(x)) names(x)[names(x) == "Performance_Score"] <- "Performance-Score"
   if ("Wu_Hausman" %in% names(x)) names(x)[names(x) == "Wu_Hausman"] <- "Wu & Hausman"
   if ("p(Wu_Hausman)" %in% names(x)) names(x)[names(x) == "p(Wu_Hausman)"] <- "p(Wu & Hausman)"
+  if ("weak_instruments" %in% names(x)) names(x)[names(x) == "weak_instruments"] <- "Weak instruments"
+  if ("weak_instruments_p" %in% names(x)) names(x)[names(x) == "weak_instruments_p"] <- "p(Weak instruments)"
 
   # Formatting if we have IC and IC weight columns ----
 
@@ -856,10 +853,10 @@ format_table <- function(x,
   win_os <- tryCatch(
     {
       si <- Sys.info()
-      if (!is.null(si["sysname"])) {
-        si["sysname"] == "Windows" || startsWith(R.version$os, "mingw")
-      } else {
+      if (is.null(si["sysname"])) {
         FALSE
+      } else {
+        si["sysname"] == "Windows" || startsWith(R.version$os, "mingw")
       }
     },
     error = function(e) {
